﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Infragistics.Win.UltraWinGrid;
using Infragistics.Win;
using Infragistics.Win.UltraWinEditors;

namespace WindowsFormsApplication58
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();

            // Assign the CreationFilter to the grid, which will handle the enabled state of the spin buttons.
            this.ultraGrid1.CreationFilter = new EnableButtonsCreationFilter();
        }

        private void ultraGrid1_InitializeLayout(object sender, Infragistics.Win.UltraWinGrid.InitializeLayoutEventArgs e)
        {
            // Assign an UltraNumericEditor to the grid with a couple of buttons to increment/decrement 
            // the value. 
            e.Layout.Bands[0].Columns[0].EditorComponent = this.ultraNumericEditor1;

            // Set MinValue and MaxValue
            e.Layout.Bands[0].Columns[0].MaxValue = 10;
            e.Layout.Bands[0].Columns[0].MinValue = 0;
        }

        private void ultraNumericEditor1_EditorButtonClick(object sender, Infragistics.Win.UltraWinEditors.EditorButtonEventArgs e)
        {
            UltraGridCell cell = (UltraGridCell)e.Context;
            int cellValue = (int)cell.Value;

            switch (e.Button.Key)
            {
                case "Plus": 
                    // Increment the cell value by 1
                    cell.Value = cellValue + 1;
                    break;
                case "Minus":
                    // Decement the cell value by 1
                    cell.Value = cellValue - 1;
                    break;
            }
        }      
    }

    public class EnableButtonsCreationFilter : IUIElementCreationFilter
    {
        #region IUIElementCreationFilter Members

        void IUIElementCreationFilter.AfterCreateChildElements(UIElement parent)
        {
            // Watch for EditorButtonUIElements
            if (parent is EditorButtonUIElement)
            {
                // Get the button from the element. We only need the button so we can get it's
                // key and determine if this is the Plus or the Minus button. 
                EditorButtonBase editorButton = parent.GetContext(typeof(EditorButtonBase)) as EditorButtonBase;
                if (editorButton != null)
                {
                    // Get the cell. We need the cell in order to determine it's current value and also
                    // the MinValue or MaxValue of the column. 
                    UltraGridCell cell = parent.GetContext(typeof(UltraGridCell)) as UltraGridCell;
                    
                    if (cell != null)
                    {
                        // Get the current value of the cell. 
                        int cellValue = (int)cell.Value;

                        switch (editorButton.Key)
                        {
                            case "Plus":
                                // Disable the Plus button when the cells value is at or above the MaxValue. 
                                int maxValue = (int)cell.Column.MaxValue;                                
                                parent.Enabled = cellValue < maxValue;
                                break;
                            case "Minus":
                                // Disable the Minus button when the cells value is at or below the MinValue. 
                                int minValue = (int)cell.Column.MinValue;                                
                                parent.Enabled = cellValue > minValue;
                                break;
                        }                        
                    }
                }
            }            
        }

        bool IUIElementCreationFilter.BeforeCreateChildElements(UIElement parent)
        {
            // Do nothing.
            return false;
        }

        #endregion
    }

}
